===============================
holes
===============================

.. image:: https://img.shields.io/travis/DouglasCAllan/holes.svg
        :target: https://travis-ci.org/DouglasCAllan/holes

.. image:: https://img.shields.io/pypi/v/holes.svg
        :target: https://pypi.python.org/pypi/holes


Python package for doing science.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://DouglasCAllan.github.io/holes.

Features
--------

* TODO
